@@ -1,14 +1,14 @@
-# $Id: dea.R 151 2015-07-07 07:09:13Z B002961 $
+# $Id: dea.R 182 2018-05-10 11:52:55Z lao $
 
 # DEA beregning via brug af lp_solveAPI. Fordelene ved lp_solveAPI er
-# faerre kald fra R med hele matricer for hver firm og dermed skulle
+# faerre kald fra R med hele matricer for hver unit og dermed skulle
 # det gerne vaere en hurtigere metode.  Maaske er det ogsaa lettere at
 # gennemskue hvad der bliver gjort en gang for alle og hvad der bliver
-# aendret ved beregning for hver firm.
+# aendret ved beregning for hver unit.
 
 # Option FAST=TRUE giver en meget hurtigere beregning af efficienser,
 # men tilgaengaeld bliver der IKKE gemt de beregnede lambdaer.  Det
-# betyder bl.a. at der ikke kan findes peers for de enkelte firms.
+# betyder bl.a. at der ikke kan findes peers for de enkelte units.
 
 
 dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
@@ -18,19 +18,19 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
    # FRONT.IDX index for units that determine the technology
 
    # In the calculation in the method input/output matrices X and Y
-   # are of the order good x firms.  
+   # are of the order good x units.  
 
    # TRANSPOSE the restriction matrix is transposed, For TRUE then X and Y are
-   # matrices of dimension inputs/ouputs times number of firms, i.e.
+   # matrices of dimension inputs/ouputs times number of units, i.e.
    # goods are rows, and therefore X, Y etc must be transformed
-   # as default in R is firm x good.
+   # as default in R is unit x good.
 
    if ( FAST ) { 
       DUAL=FALSE; # SLACK=FALSE; 
       # print("When  FAST then neither DUAL nor SLACK") 
    }
 
-   rts <- c("fdh","vrs","drs","crs","irs","irs2","add","fdh+","fdh++","fdh0")
+   rts <- c("fdh","vrs","drs","crs","irs","irs2","add","fdh+","fdh++","fdh0", "vrs+")
    if ( missing(RTS) ) RTS <- "vrs" 
    if ( is.numeric(RTS) )  {
       if (LP) print(paste("Number '",RTS,"'",sep=""),quote=F)
@@ -64,7 +64,7 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
 
    if ( class(X)!="matrix" || !is.numeric(X) )
       stop("X is not a numeric matrix (or data.frame)")
-   if ( class(Y)!="matrix" || !is.numeric(X) )
+   if ( class(Y)!="matrix" || !is.numeric(Y) )
       stop("Y is not a numeric matrix (or data.frame)")
    if ( !is.null(XREF) && (class(XREF)!="matrix" || !is.numeric(XREF)) )
       stop("XREF is not a numeric matrix (or data.frame)")
@@ -106,9 +106,9 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
 
    m <- dim(X)[2]  # number of inputs
    n <- dim(Y)[2]  # number of outputs
-   K <- dim(X)[1]  # number of units, firms, DMUs
+   K <- dim(X)[1]  # number of units, units, DMUs
    Ky <- dim(Y)[1]  
-   Kr <- dim(XREF)[1] # number of units,firms in the reference technology
+   Kr <- dim(XREF)[1] # number of units,units in the reference technology
    oKr <- orgKr[1]
    if ( !is.null(DIRECT) )  {
       if ( class(DIRECT)=="matrix" ) {
@@ -145,7 +145,7 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
       else if ( ORIENTATION=="in-out" & md!=m+n )
          stop("Length of DIRECT must be the number of inputs plus outputs")
       if ( class(DIRECT)=="matrix" & (Kd>0 & Kd!=K) )
-         stop("Number of firms in DIRECT must equal firms in X and Y") 
+         stop("Number of units in DIRECT must equal units in X and Y") 
    }
    if ( !is.null(DIRECT) & length(DIRECT) == 1 )  {
       if ( ORIENTATION=="in" & length(DIRECT)!=m )
@@ -190,7 +190,9 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
                             ORIENTATION,RTS,dirStreng,sep="-"))
 
    # saet raekker i matrix med restriktioner, saet 0'er for den foerste
-   # soejle for den skal alligevel aendres for hver firm.
+   # soejle for den skal alligevel aendres for hver unit.
+   # Bemaerk X og Y transponeres implicit naar de saettes i lp_solveAPI; 
+   # soejler i X og Y saettes so raekker i lp_solveAPI.
    # Foerste 'm' raekker med input
    for ( h in 1:m )
        set.row(lps,h, c(0,-XREF[,h]))
@@ -210,7 +212,29 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
       rlamb <- rlamb -1
    } else if ( RTS == "vrs" )  {
       set.rhs(lps, c(-1,1), (m+n+1):(m+n+2))
-   } else if ( RTS == "drs" )  {
+   } else if ( RTS == "vrs+" )  {
+   	# param: (lav, hoej, sum lav, sum hoej)
+      # Saet parametrene low og high
+      if ( is.null(param) )  {
+         param <- c(.5, 2.)
+      }
+      if ( length(param) == 1 )  {
+         low <- param
+         high <- 1+(1-param)
+      } else {
+         low <- param[1]
+         high <- param[2]
+      }
+      if (length(param) == 4)  {
+			# print("Graenser for sum af lambda sat")
+			set.rhs(lps, c(-param[4], param[3]), (m+n+1):(m+n+2))
+		} else {
+			set.rhs(lps, c(-1,1), (m+n+1):(m+n+2))
+		}
+		param <- c(low=low, high=high)
+		set.semicont(lps, 2:(1+Kr))
+		set.bounds(lps, lower=rep(low,Kr), upper=rep(high,Kr), columns=2:(1+Kr))
+	} else if ( RTS == "drs" )  {
       set.rhs(lps, -1, m+n+1)
       delete.constraint(lps, m+n+2)
       rlamb <- rlamb -1
@@ -311,7 +335,7 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
          primal <- NULL
          dual <- NULL
       }
-   }  
+   }
 
    if ( !is.null(DIRECT) && DIRECT[1] == "min" )  {
       directMin <- TRUE
@@ -326,9 +350,9 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
       directMin <- FALSE
    }
 
-   # The loop for each firm
+   # The loop for each unit
    for ( k in 1:K)  {
-      if ( LP )  print(paste("Firm",k," -------------------"), quote=FALSE)
+      if ( LP )  print(paste("Unit",k," -------------------"), quote=FALSE)
  
       # Af en eller anden grund saetter set.column ogsaa vaerdi for
       # kriteriefunktion og hvis der ikke er nogen vaerdi bliver den
@@ -356,7 +380,7 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
          directMatrix[k,] <- DIRECT
          if (LP) { print("Min DIRECT:"); print(DIRECT) }
 
-         # Check om DIRECT er 0, hvis den er nul gaa til naeste firm
+         # Check om DIRECT er 0, hvis den er nul gaa til naeste unit
          lpcontr <- lp.control(lps)
          eps <- sqrt(lpcontr$epsilon["epsint"])
          if (LP) print(paste("eps for minDirectin",eps), quote=FALSE)
@@ -372,13 +396,13 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
 
          if ( max(DIRECT) < eps && max(abs(deltaDir)) < eps )
          {
-            if (LP) print(paste("Direction 0 for firm",k))
+            if (LP) print(paste("Direction 0 for unit",k))
             objval[k] <- 0
             if ( !FAST )  {
                lambda[k,] <- rep(0,Kr)
                lambda[k,k] <- 1
             }
-            next  # ingen direction at gaa, tag naeste firm
+            next  # ingen direction at gaa, tag naeste unit
          }
       }  # if ( directMin )
 
@@ -405,6 +429,9 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
                set.column(lps, 1, c(1,-DIRECT[k,]),0:(m+n))
          }
       }
+      # Default scalering goer af og til, at en loesning ikke kan findes; laves
+      # foer evt CONTROL fra kald saettes saa den kan aendres her.
+      # lp.control(lps, scaling=c("range", "equilibrate", "integers"))
       if ( !is.null(CONTROL) )  {
          if( !is.list(CONTROL)) {
             stop( "argument 'control' must be a 'list' object")
@@ -422,11 +449,11 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
       if (LP)  print(paste("Status =",status))
       if ( status != 0 )  {
         if ( status == 2 || status == 3 ) {
-	        # print(paste("Firm",k,"not in the technology set"), quote=F)
-           # print(paste("Status =",status))
+	       print(paste("Unit",k,"is not in the technology set.", 
+				" Status =",status), quote=F)
            objval[k] <- ifelse(ORIENTATION=="in",Inf,-Inf)
         } else {
-	        print(paste("Error in solving for firm",k,":  Status =",status), 
+	        print(paste("Error in solving for unit",k,":  Status =",status), 
              quote=F)
            objval[k] <- NA
         }
@@ -444,9 +471,9 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
       }
 
    	if (LP && status==0) {
-         print(paste("Objval, firm",k))
+         print(paste("Objval, unit",k))
          print(get.objective(lps))
-         print("Solution/varaibles")
+         print("Solution/variables")
          print(get.variables(lps))
          print("Primal solution")
          print(get.primal.solution(lps))
@@ -458,13 +485,13 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
          write.lp(lps, paste(name.lp(lps),k,".mps",sep=""),
                 type="mps",use.names=TRUE)
       }
-   }  # loop for each firm
+   }  # loop for each unit
 
    e <- objval
 
 
    lpcontr <- lp.control(lps)
-   eps <- sqrt(lpcontr$epsilon["epsint"])
+   eps <- lpcontr$epsilon["epsint"]
    e[abs(e-1) < eps] <- 1
    if ( !is.null(dimnames(X)[[1]]) )  {
       names(e) <- dimnames(X)[[1]]
@@ -535,9 +562,9 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
 
    oe <- list(eff=e, lambda=lambda, objval=objval, RTS=RTS,
               primal=primal, dual=dual, ux=ux, vy=vy, gamma=gamma,
-              ORIENTATION=ORIENTATION, TRANSPOSE=TRANSPOSE
-              # ,slack=slack_, sx=sx, sy=sy 
-              , param=param 
+              ORIENTATION=ORIENTATION, TRANSPOSE=TRANSPOSE,
+              # slack=NULL, sx=NULL, sy=NULL, sum=NULL, 
+              param=param 
               )
 
    if (!is.null(DIRECT))  {
@@ -547,8 +574,8 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
    class(oe) <- "Farrell"
 
 
-   if ( SLACK ) {
-      if ( TRANSPOSE )  { # Transponer tilbage hvis de blev transponeret
+	if ( SLACK ) {
+	     if ( TRANSPOSE )  { # Transponer tilbage hvis de blev transponeret
          X <- t(X)
          Y <- t(Y)
          if (.xyref.missing) {
@@ -571,7 +598,7 @@ dea  <-  function(X,Y, RTS="vrs", ORIENTATION="in", XREF=NULL,YREF=NULL,
          print("slack efter slack:")
          print(oe$slack)
       }
-   }
+	}
 
    return(oe)
 
